@@ -2,8 +2,10 @@
 
 package App::WHMCSUtils;
 
-our $DATE = '2019-11-12'; # DATE
-our $VERSION = '0.010'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2019-11-29'; # DATE
+our $DIST = 'App-WHMCSUtils'; # DIST
+our $VERSION = '0.011'; # VERSION
 
 use 5.010001;
 use strict;
@@ -331,13 +333,17 @@ $SPEC{calc_deferred_revenue} = {
     v => 1.1,
     description => <<'_',
 
-Deferring revenue is the process of recognizing revenue as you have earned it,
-in contrast to as you have received the cash. This is the principle of accrual
-accounting, as opposed to cash-based accounting. For example, if you receive an
-amount of $12 for 12 months of hosting, you then recognize $1 revenue for each
-month you are performing the hosting obligation, for 12 times.
+Deferring revenue is the process of recognizing revenue as you earn it, in
+contrast to as you receive the cash. This is the principle of accrual
+accounting, as opposed to cash-based accounting.
 
-For example, suppose you have three invoices:
+For example, suppose on Nov 1, 2019 you receive an amount of $12 for 12 months
+of hosting (up until Oct 31, 2020). In cash-based accounting, you immediately
+recognize the $12 as revenue on Nov 1, 2019. In accrual accounting, you
+recognize $1 revenue for each month you are performing the hosting obligation,
+for 12 times, from Nov 2019 to Oct 2020.
+
+As another example, suppose you have three invoices:
 
     invoice num    type                  amount    note
     -----------    ------                ------    ----
@@ -807,7 +813,7 @@ _
         include_client_ids => {
             #'x.name.is_plural' => 1,
             #'x.name.singular' => 'include_client_id',
-            schema => ['array*', of=>'uint*', 'x.perl.coerce_rules'=>['str_comma_sep']],
+            schema => ['array*', of=>'uint*', 'x.perl.coerce_rules'=>['From_str::comma_sep']],
             tags => ['category:filtering'],
         },
         include_client_ids_from => {
@@ -930,7 +936,7 @@ App::WHMCSUtils - CLI utilities related to WHMCS
 
 =head1 VERSION
 
-This document describes version 0.010 of App::WHMCSUtils (from Perl distribution App-WHMCSUtils), released on 2019-11-12.
+This document describes version 0.011 of App::WHMCSUtils (from Perl distribution App-WHMCSUtils), released on 2019-11-29.
 
 =head1 FUNCTIONS
 
@@ -941,13 +947,17 @@ Usage:
 
  calc_deferred_revenue(%args) -> [status, msg, payload, meta]
 
-Deferring revenue is the process of recognizing revenue as you have earned it,
-in contrast to as you have received the cash. This is the principle of accrual
-accounting, as opposed to cash-based accounting. For example, if you receive an
-amount of $12 for 12 months of hosting, you then recognize $1 revenue for each
-month you are performing the hosting obligation, for 12 times.
+Deferring revenue is the process of recognizing revenue as you earn it, in
+contrast to as you receive the cash. This is the principle of accrual
+accounting, as opposed to cash-based accounting.
 
-For example, suppose you have three invoices:
+For example, suppose on Nov 1, 2019 you receive an amount of $12 for 12 months
+of hosting (up until Oct 31, 2020). In cash-based accounting, you immediately
+recognize the $12 as revenue on Nov 1, 2019. In accrual accounting, you
+recognize $1 revenue for each month you are performing the hosting obligation,
+for 12 times, from Nov 2019 to Oct 2020.
+
+As another example, suppose you have three invoices:
 
  invoice num    type                  amount    note
  -----------    ------                ------    ----
